@@ -25,11 +25,11 @@ class VGroupHighlightShowcase(ShowcaseScene):
 
         group = VGroupHighlight(*dots, anim_run_time=1, anim_lag_ratio=0.1)
         self.add(group)
-        group.highlight(self, 0)
-        group.highlight(self, 1)
-        group.highlight(self, [2, 3])
-        group.highlight(self, [1, 3])
-        group.highlight(self, [])
-        group.highlight(self, [2, 4])
-        group.highlight(self, [])
+        self.play(group.highlight(0))
+        self.play(group.highlight(1))
+        self.play(group.highlight([2, 3]))
+        self.play(group.highlight([1, 3]))
+        self.play(group.highlight([]))
+        self.play(group.highlight([2, 4]))
+        self.play(group.highlight([]))
         self.wait(0.5)
